"""Base Provider for providing donations"""


class DonationProvider(object):

    def __init__(self, donation):
        self.amount = donation.amount
        self.currency = donation.amount.currency
        self.donation_status = donation.status
        self.donation = donation

    def get_value(self):
        return self.amount.amount

    def get_currency(self):
        return self.currency

    def donate(self, verify_uri):
        """Make the api calls to give money
        Given this library is not handling payment details this should
        simply construct the url to redirect to on the 3rd party provider site"""
        raise NotImplementedError

    def verify(self, request):
        """
        Optional method to verify donation has been successfully received
        Should return True if verified correctly or False otherwise
        """
        raise NotImplementedError



SETTINGS = {
    'INSTALLED_APPS': [
        'django.contrib.auth',
        'rest_framework',
        'south',
        'donations'
    ],
    'DONATION_FREQUENCIES': {
        'single': '0 days',
    },
    'DONATION_PROVIDERS': {
        'Just Giving': 'just_giving.SimpleDonationProvider'
    }
}



"""Setup file for django-donations."""
from setuptools import setup
# from setuptest import test

from donations import __version__, __version_info__

setup(
    name='django-donations',
    version=__version__,
    packages=['donations', 'donations.migrations', 'donations.providers'],
    author='Andrew Miller',
    author_email='andrew.miller@founders4schools.org.uk',
    description='Reusable backend to accept & track donations to your site',
    long_description=open('README.rst').read(),
    url='https://github.com/founders4schools/django-donations/',
    install_requires=[
        'django >= 1.6, <1.7',
        'django-autoconfig',
        'django-money',
        # this should be replaced when we upgrade to 1.8
        'django-timedeltafield',
        'djangorestframework',
        'requests',
        'South',
        'py-moneyed',
        'django-environ'
    ],
    tests_require=['django-setuptest'],
    # cmdclass={'test': test},
    test_suite='setuptest.setuptest.SetupTestSuite',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
)



from rest_framework import serializers
from .models import Donation, DonationProvider, Frequency
from moneyed import Money


class DonationSerializer(serializers.ModelSerializer):
    amount = serializers.DecimalField(label='amount', max_digits=10, decimal_places=2, source='amount.amount')
    currency = serializers.CharField(label='amount', source='amount.currency')
    frequency = serializers.SlugRelatedField(queryset=Frequency.objects.all(), slug_field='name')
    provider = serializers.SlugRelatedField(queryset=DonationProvider.objects.all(), slug_field='name')

    class Meta:  # pylint: disable=C1001
        model = Donation
        fields = ('id', 'amount', 'currency', 'provider', 'frequency')
        depth = 1

    def create(self, validated_data):
        kwargs = {
            'provider': validated_data['provider'],
            'frequency': validated_data['frequency'],
            'amount': Money(**validated_data['amount'])
        }
        return Donation.objects.create(**kwargs)




from django.conf import settings

JUST_GIVING_WEB_URL = getattr(settings, 'JUST_GIVING_WEB_URL', 'http://v3-sandbox.justgiving.com')
JUST_GIVING_API_URL = getattr(settings, 'JUST_GIVING_API_URL', 'http://api-sandbox.justgiving.com')
# JUST_GIVING_CHARITY_ID = '265263' # founders4schools id
JUST_GIVING_CHARITY_ID = getattr(settings, 'JUST_GIVING_CHARITY_ID', '2050')  # demo id
JUST_GIVING_APP_ID = getattr(settings, 'JUST_GIVING_APP_ID', 'XXXXX')
# JUST_GIVING_APP_ID = '7caeb2c2'

CURRENCIES = getattr(settings, 'CURRENCIES', ['GBP', 'EUR', 'AUD', 'USD', 'ZAR', 'CAD', 'AED', 'HKD', 'SGD'])

DONATION_FREQUENCIES = getattr(settings, 'DONATION_FREQUENCIES', {})
DONATION_PROVIDERS = getattr(settings, 'DONATION_PROVIDERS', {})
